==> phoenix-starter-rosefinch-0.1.0.1-20240807.081053-1-sources.jar: com/elitesland/cbpl/rosefinch/data/vo/resp/RosefinchInstancePagingVO.java <==
package com.elitesland.cbpl.rosefinch.data.vo.resp;

import com.elitesland.cbpl.rosefinch.constant.InstanceStatus;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * 任务实例表
 *
 * @author eric.hao
 * @since 2024/08/06
 */
@Data
@ApiModel("任务实例表")
public class RosefinchInstancePagingVO implements Serializable {

	private static final long serialVersionUID = 5964300840129048268L;

	@ApiModelProperty(value = "主键")
	private Long id;

	@ApiModelProperty(value = "任务ID")
	private Long masId;

	@ApiModelProperty(value = "定时任务名称")
	private String taskName;

	@ApiModelProperty(value = "定时任务编码")
	private String taskCode;

	@ApiModelProperty(value = "执行方式：AUTO自动执行；INVOKE手动执行；")
	private String runType;

	@ApiModelProperty(value = "日志行状态")
	private String instanceStatus;

	@JsonProperty
	public String getInstanceStatusName() {
		return InstanceStatus.fromCode(instanceStatus);
	}

	@ApiModelProperty(value = "开始时间")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private LocalDateTime startTime;

	@ApiModelProperty(value = "执行时间")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private LocalDateTime executeTime;

	@ApiModelProperty(value = "结束时间")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private LocalDateTime endTime;

	@ApiModelProperty(value = "错误日志")
	private String errorMessage;

	@ApiModelProperty(value = "日志链路ID")
	private String traceId;

	@ApiModelProperty(value = "自定义字段(JSON字符串)")
	private String customFields;

	@ApiModelProperty(value = "备注")
	private String remark;
}

==> phoenix-starter-rosefinch-0.1.0.23-20240820.011926-1-sources.jar: com/elitesland/cbpl/rosefinch/data/vo/resp/RosefinchInstancePagingVO.java <==
package com.elitesland.cbpl.rosefinch.data.vo.resp;

import com.elitesland.cbpl.rosefinch.enums.InstanceStatus;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * 任务实例表
 *
 * @author eric.hao
 * @since 2024/08/06
 */
@Data
@ApiModel("任务实例表")
public class RosefinchInstancePagingVO implements Serializable {

	private static final long serialVersionUID = 5964300840129048268L;

	@ApiModelProperty(value = "主键")
	private Long id;

	@ApiModelProperty(value = "任务ID")
	private Long masId;

	@ApiModelProperty(value = "定时任务名称")
	private String taskName;

	@ApiModelProperty(value = "定时任务编码")
	private String taskCode;

	@ApiModelProperty(value = "执行方式：AUTO自动执行；INVOKE手动执行；")
	private String runType;

	@ApiModelProperty(value = "日志行状态")
	private String instanceStatus;

	@JsonProperty
	public String getInstanceStatusName() {
		return InstanceStatus.fromCode(instanceStatus);
	}

	@ApiModelProperty(value = "开始时间")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private LocalDateTime startTime;

	@ApiModelProperty(value = "执行时间")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private LocalDateTime executeTime;

	@ApiModelProperty(value = "结束时间")
	@JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
	private LocalDateTime endTime;

	@ApiModelProperty(value = "错误日志")
	private String errorMessage;

	@ApiModelProperty(value = "日志链路ID")
	private String traceId;

	@ApiModelProperty(value = "自定义字段(JSON字符串)")
	private String customFields;

	@ApiModelProperty(value = "备注")
	private String remark;
}
